@@ -11,6 +11,8 @@ var gToolboxDocument = null;
 var gToolbox = null;
 var gCurrentDragOverItem = null;
 var gToolboxChanged = false;
+var gPreviousMode = null;
+var gPreviousIconSize = null;
 
 function onLoad()
 {
@@ -29,19 +31,16 @@ function onLoad()
 function onUnload(aEvent)
 {
   removeToolboxListeners();
-  unwrapToolbarItems();
+  unwrapToolbarItems(true);
   persistCurrentSets();
   
   notifyParentComplete();
-
-  window.close();
 }
 
 function onCancel()
 {
   // restore the saved toolbarset for each customizeable toolbar
-
-  // Restore the defaultset for fixed toolbars.
+  unwrapToolbarItems(false);
   var toolbar = gToolbox.firstChild;
   while (toolbar) {
     if (isCustomizableToolbar(toolbar)) {
@@ -56,11 +55,9 @@ function onCancel()
     toolbar = toolbar.nextSibling;
   }
 
-  // Now rebuild the palette.
-  buildPalette();
-
-  // Now re-wrap the items on the toolbar.
-  wrapToolbarItems();
+  // restore the previous mode and iconsize
+  updateIconSize(gPreviousIconSize == "small");
+  updateToolbarMode(gPreviousMode);
 
   repositionDialog();
   gToolboxChanged = true;
@@ -78,20 +75,20 @@ function initDialog()
 {
   document.getElementById("main-box").collapsed = false;
   
-  var mode = gToolbox.getAttribute("mode");
-  document.getElementById("modelist").value = mode;
-  var iconSize = gToolbox.getAttribute("iconsize");
+  gPreviousMode = gToolbox.getAttribute("mode");
+  document.getElementById("modelist").value = gPreviousMode;
+  gPreviousIconSize = gToolbox.getAttribute("iconsize");
   var smallIconsCheckbox = document.getElementById("smallicons");
-  if (mode == "text")
+  if (gPreviousMode == "text")
     smallIconsCheckbox.disabled = true;
   else
-    smallIconsCheckbox.checked = iconSize == "small"; 
+    smallIconsCheckbox.checked = gPreviousIconSize == "small";
 
   // Build up the palette of other items.
   buildPalette();
 
   // Wrap all the items on the toolbar in toolbarpaletteitems.
-  wrapToolbarItems();
+  wrapToolbarItems(true);
 }
 
 function repositionDialog()
@@ -183,13 +180,13 @@ function persistCurrentSets()
 /**
  * Wraps all items in all customizable toolbars in a toolbox.
  */
-function wrapToolbarItems()
+function wrapToolbarItems(aStorePreviousSet)
 {
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      // save off the current set for each toolbar in case the user hits cancel
-      toolbar.setAttribute('previousset', toolbar.currentSet);
+      if (aStorePreviousSet)
+        toolbar.setAttribute('previousset', toolbar.currentSet);
 
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var item = toolbar.childNodes[k];
@@ -210,17 +207,19 @@ function wrapToolbarItems()
 /**
  * Unwraps all items in all customizable toolbars in a toolbox.
  */
- function unwrapToolbarItems()
+ function unwrapToolbarItems(aRemovePreviousSet)
 {
   for (var i = 0; i < gToolbox.childNodes.length; ++i) {
     var toolbar = getToolbarAt(i);
     if (isCustomizableToolbar(toolbar)) {
-      toolbar.removeAttribute('previousset'); // remove previous set attribute
+      if (aRemovePreviousSet)
+        toolbar.removeAttribute('previousset');
+
       for (var k = 0; k < toolbar.childNodes.length; ++k) {
         var paletteItem = toolbar.childNodes[k];
         var toolbarItem = paletteItem.firstChild;
 
-        if (isToolbarItem(toolbarItem)) {
+        if (toolbarItem && isToolbarItem(toolbarItem)) {
           var nextSibling = paletteItem.nextSibling;
 
           if (paletteItem.hasAttribute("itemcommand"))
@@ -538,6 +537,7 @@ function setDragActive(aItem, aValue)
 function restoreDefaultSet()
 {
   // Restore the defaultset for fixed toolbars.
+  unwrapToolbarItems(false);
   var toolbar = gToolbox.firstChild;
   while (toolbar) {
     if (isCustomizableToolbar(toolbar)) {
@@ -552,6 +552,12 @@ function restoreDefaultSet()
     toolbar = toolbar.nextSibling;
   }
 
+  // Restore the default icon size (large) and mode (icons and text).
+  updateIconSize(false);
+  document.getElementById("smallicons").checked = false;
+  updateToolbarMode("full");
+  document.getElementById("modelist").value = "full";
+
   // Remove all of the customized toolbars.
   var child = gToolbox.lastChild;
   while (child) {
@@ -567,8 +573,8 @@ function restoreDefaultSet()
   // Now rebuild the palette.
   buildPalette();
 
-  // Now re-wrap the items on the toolbar.
-  wrapToolbarItems();
+  // Now re-wrap the items on the toolbar, but don't clobber previousset.
+  wrapToolbarItems(false);
 
   repositionDialog();
   gToolboxChanged = true;
@@ -606,14 +612,7 @@ function updateToolbarMode(aModeValue)
   }
 
   var iconSizeCheckbox = document.getElementById("smallicons");
-  if (aModeValue == "text") {
-    iconSizeCheckbox.disabled = true;
-    iconSizeCheckbox.checked = false;
-    updateIconSize(false);
-  }
-  else {
-    iconSizeCheckbox.disabled = false;
-  }
+  iconSizeCheckbox.disabled = aModeValue == "text";
 
   repositionDialog();
 }
