@@ -480,7 +480,7 @@ var gFeedSubscriptionsWindow = {
       return;
 
     var resource = rdf.GetResource(itemToRemove.url);
-    var feed = new Feed(resource);
+    var feed = new Feed(resource, this.mRSSServer);
     var ds = getSubscriptionsDS(this.mRSSServer);
 
     if (feed && ds)
@@ -819,7 +819,7 @@ var gFeedSubscriptionsWindow = {
       else if(rv)
       {
         //debug("opml:\n"+serial.serializeToString(opmlDoc)+"\n");
-        var file = new LocalFile(rv.file, MODE_WRONLY | MODE_CREATE);
+        var file = new LocalFile(rv.file, MODE_WRONLY | MODE_CREATE | MODE_TRUNCATE);
         serial.serializeToStream(opmlDoc,file.outputStream,'utf-8');
         file.close();
       }
